==> haskell-cabal-doctest-1.0.9-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-doctest
version:              1.0.9
visibility:           public
id:                   cabal-doctest-1.0.9-9n1O6JDXm2AKiBqLDOu4Wa
key:                  cabal-doctest-1.0.9-9n1O6JDXm2AKiBqLDOu4Wa
license:              BSD-3-Clause
copyright:            (c) 2017 Oleg Grenrus
maintainer:           Andreas Abel
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/haskellari/cabal-doctest
synopsis:             A Setup.hs helper for running doctests
description:
    As of now (end of 2021), there isn'\''t @cabal doctest@
    command. Yet, to properly work, @doctest@ needs plenty of configuration.
    This library provides the common bits for writing a custom @Setup.hs@.

category:             Distribution
abi:                  8b9bdad159fcc28fac6e37c5ed161ca2
exposed:              True
exposed-modules:      Distribution.Extra.Doctest
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cabal-doctest-1.0.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cabal-doctest-1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-doctest
hs-libraries:         HScabal-doctest-1.0.9-9n1O6JDXm2AKiBqLDOu4Wa
depends:
    Cabal-3.6.3.0 base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock

haddock-html:         /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cabal-doctest-1.0.10-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cabal-doctest.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cabal-doctest
version:              1.0.10
visibility:           public
id:                   cabal-doctest-1.0.10-6A4I1ew03S97cpnx2YAS7s
key:                  cabal-doctest-1.0.10-6A4I1ew03S97cpnx2YAS7s
license:              BSD-3-Clause
copyright:            (c) 2017-2020 Oleg Grenrus, 2020- package maintainers
maintainer:           Max Ulidtko <ulidtko@gmail.com>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/ulidtko/cabal-doctest
synopsis:             A Setup.hs helper for running doctests
description:
    As of now (end of 2021), there isn'\''t @cabal doctest@
    command. Yet, to properly work, @doctest@ needs plenty of configuration.
    This library provides the common bits for writing a custom @Setup.hs@.

category:             Distribution
abi:                  9a182159a16ceda8df0db8b193044d50
exposed:              True
exposed-modules:      Distribution.Extra.Doctest
import-dirs:          /usr/lib/ghc-9.2.8/site-local/cabal-doctest-1.0.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cabal-doctest-1.0.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cabal-doctest
hs-libraries:         HScabal-doctest-1.0.10-6A4I1ew03S97cpnx2YAS7s
depends:
    Cabal-3.6.3.0 base-4.16.4.0 directory-1.3.6.2 filepath-1.4.2.2

haddock-interfaces:
    /usr/share/doc/haskell-cabal-doctest/html/cabal-doctest.haddock

haddock-html:         /usr/share/doc/haskell-cabal-doctest/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
